@@ -1,82 +1,76 @@
-# $Id: Phylo.pm 1641 2011-03-30 17:27:58Z rvos $
+# $Id: Phylo.pm 1660 2011-04-02 18:29:40Z rvos $
 package Bio::Phylo;
 use strict;
+use base 'Bio::Phylo::Identifiable';
 
-# we don't use 'our', for 5.005 compatibility
-use vars qw($VERSION $COMPAT $logger @ISA);
+# ABSTRACT: Phyloinformatic analysis using Perl
 
 # Because we use a roll-your-own looks_like_number from
 # Bio::Phylo::Util::CONSTANT, here we don't have to worry
 # about older core S::U versions that don't have it...
-use Scalar::Util qw(weaken blessed);
+use Scalar::Util qw'weaken blessed';
 
 #... instead, Bio::Phylo::Util::CONSTANT can worry about it
 # in one location, perhaps using the S::U version, or a drop-in
-use Bio::Phylo::Util::CONSTANT qw(
-    looks_like_number
-    looks_like_hash
-    looks_like_instance
-);
-use Bio::Phylo::Util::IDPool;             # creates unique object IDs
-use Bio::Phylo::Identifiable;             # for storing unique IDs inside an instance
+use Bio::Phylo::Util::CONSTANT '/looks_like/';
+use Bio::Phylo::Util::IDPool;    # creates unique object IDs
+use Bio::Phylo::Identifiable;    # for storing unique IDs inside an instance
 use Bio::Phylo::Util::Exceptions 'throw'; # defines exception classes and throws
-use Bio::Phylo::Util::Logger;             # for logging, like log4perl/log4j 
+use Bio::Phylo::Util::Logger;             # for logging, like log4perl/log4j
+our ( $logger, $COMPAT ) = Bio::Phylo::Util::Logger->new;
 
-BEGIN {
-	@ISA = qw(Bio::Phylo::Identifiable);
-    $logger = Bio::Phylo::Util::Logger->new;
-}
-
-# mediates one-to-many relationships between taxon and nodes, 
+# mediates one-to-many relationships between taxon and nodes,
 # taxon and sequences, taxa and forests, taxa and matrices.
 # Read up on the Mediator design pattern to learn how this works.
-require Bio::Phylo::Mediators::TaxaMediator;  
+require Bio::Phylo::Mediators::TaxaMediator;
 
 # Include the revision number from subversion in $VERSION
-my $rev = '$Id: Phylo.pm 1641 2011-03-30 17:27:58Z rvos $';
+my $rev = '$Id: Phylo.pm 1660 2011-04-02 18:29:40Z rvos $';
 $rev =~ s/^[^\d]+(\d+)\b.*$/$1/;
-$VERSION = "0.36";
+our $VERSION = "0.37";
 $VERSION .= "_$rev";
 {
     my $taxamediator = 'Bio::Phylo::Mediators::TaxaMediator';
+
     sub import {
         my $class = shift;
         if (@_) {
-		my %opt = looks_like_hash @_;
-		while ( my ( $key, $value ) = each %opt ) {
-			if ( $key =~ qr/^VERBOSE$/i ) {
-				$logger->VERBOSE( '-level' => $value, -class => $class );
-			}
-			elsif ( $key =~ qr/^COMPAT$/i ) {
-				$COMPAT = ucfirst( lc($value) );
-			}
-			else {
-				throw 'BadArgs' => "'$key' is not a valid argument for import";
-			}
-		}
+            my %opt = looks_like_hash @_;
+            while ( my ( $key, $value ) = each %opt ) {
+                if ( $key =~ qr/^VERBOSE$/i ) {
+                    $logger->VERBOSE( '-level' => $value, -class => $class );
+                }
+                elsif ( $key =~ qr/^COMPAT$/i ) {
+                    $COMPAT = ucfirst( lc($value) );
+                }
+                else {
+                    throw 'BadArgs' =>
+                      "'$key' is not a valid argument for import";
+                }
+            }
         }
         return 1;
     }
 
-    # the following hashes are used to hold state of inside-out objects. For 
-    # example, $obj->set_name("name") is implemented as $name{ $obj->get_id } 
-    # = $name. To avoid memory leaks (and subtle bugs, should a new object by 
-    # the same id appear (though that shouldn't happen)), the hash slots 
-    # occupied by $obj->get_id need to be reclaimed in the destructor. This 
-    # is done by recursively calling the $obj->_cleanup methods in all of $obj's 
-    # superclasses. To make that method easier to write, we create an  array 
-    # with the local inside-out hashes here, so that we can just iterate over 
-    # them anonymously during destruction cleanup. Other classes do something 
+    # the following hashes are used to hold state of inside-out objects. For
+    # example, $obj->set_name("name") is implemented as $name{ $obj->get_id }
+    # = $name. To avoid memory leaks (and subtle bugs, should a new object by
+    # the same id appear (though that shouldn't happen)), the hash slots
+    # occupied by $obj->get_id need to be reclaimed in the destructor. This
+    # is done by recursively calling the $obj->_cleanup methods in all of $obj's
+    # superclasses. To make that method easier to write, we create an  array
+    # with the local inside-out hashes here, so that we can just iterate over
+    # them anonymously during destruction cleanup. Other classes do something
     # like this as well.
-    my @fields = \( 
-	    my (
-	    	%desc, 
-	    	%score, 
-	    	%generic, 
-	    	%cache, 
-	    	%container, # XXX weak reference
-	    	%objects # XXX strong reference
-    	) 
+    my @fields = \(
+        my (
+            %desc,
+            %score,
+            %generic,
+            %cache,
+            %container,    # XXX weak reference
+            %objects       # XXX strong reference
+        )
     );
 
 =head1 NAME
@@ -155,16 +149,16 @@ argument "-name" in the constructor.
         # not the same thing as a clone.
         my $class = shift;
         if ( my $reference = ref $class ) {
-        	$class = $reference;
+            $class = $reference;
         }
 
         # notify user
         $logger->info("constructor called for '$class'");
 
         # happens only and exactly once because this
-	    # root class is visited from every constructor
-	    my $self = $class->SUPER::new();
-        
+        # root class is visited from every constructor
+        my $self = $class->SUPER::new();
+
         # register for get_obj_by_id
         my $id = $self->get_id;
         $objects{$id} = $self;
@@ -172,63 +166,65 @@ argument "-name" in the constructor.
 
         # processing arguments
         if ( @_ and @_ = looks_like_hash @_ ) {
-	
-		# process all arguments
-		ARG: while (@_) {
-			my $key   = shift @_;
-			my $value = shift @_;
-			
-			# this is a bioperl arg, meant to set
-			# verbosity at a per class basis. In
-			# bioperl, the $verbose argument is
-			# subsequently carried around in that
-			# class, here we delegate that to the
-			# logger, which has roughly the same 
-			# effect.
-			if ( $key eq '-verbose' ) {
-				$logger->VERBOSE( 
-					'-level' => $value,
-					'-class' => $class,
-				);
-				next ARG;
-			}
-	
-			# notify user
-			$logger->debug("processing constructor arg '${key}' => '${value}'");
-	
-			# don't access data structures directly, call mutators
-			# in child classes or __PACKAGE__
-			my $mutator = $key;
-			$mutator =~ s/^-/set_/;
-	
-			# backward compat fixes:
-			$mutator =~ s/^set_pos$/set_position/;
-			$mutator =~ s/^set_matrix$/set_raw/;
-			eval {
-				$self->$mutator($value);
-			};
-			if ( $@ ) {
-				if ( blessed $@ and $@->can('rethrow') ) {
-					$@->rethrow;
-				}
-				elsif ( not ref($@) and $@ =~ /^Can't locate object method / ) {
-					throw 'BadArgs' => "The named argument '${key}' cannot be passed to the constructor of ${class}";
-				}
-				else {
-					throw 'Generic' => $@;
-				}
-			}
-		}
+
+            # process all arguments
+          ARG: while (@_) {
+                my $key   = shift @_;
+                my $value = shift @_;
+
+                # this is a bioperl arg, meant to set
+                # verbosity at a per class basis. In
+                # bioperl, the $verbose argument is
+                # subsequently carried around in that
+                # class, here we delegate that to the
+                # logger, which has roughly the same
+                # effect.
+                if ( $key eq '-verbose' ) {
+                    $logger->VERBOSE(
+                        '-level' => $value,
+                        '-class' => $class,
+                    );
+                    next ARG;
+                }
+
+                # notify user
+                $logger->debug(
+                    "processing constructor arg '${key}' => '${value}'");
+
+                # don't access data structures directly, call mutators
+                # in child classes or __PACKAGE__
+                my $mutator = $key;
+                $mutator =~ s/^-/set_/;
+
+                # backward compat fixes:
+                $mutator =~ s/^set_pos$/set_position/;
+                $mutator =~ s/^set_matrix$/set_raw/;
+                eval { $self->$mutator($value); };
+                if ($@) {
+                    if ( blessed $@ and $@->can('rethrow') ) {
+                        $@->rethrow;
+                    }
+                    elsif ( not ref($@)
+                        and $@ =~ /^Can't locate object method / )
+                    {
+                        throw 'BadArgs' =>
+"The named argument '${key}' cannot be passed to the constructor of ${class}";
+                    }
+                    else {
+                        throw 'Generic' => $@;
+                    }
+                }
+            }
         }
 
         # register with mediator
-	# TODO this is irrelevant for some child classes,
-	# so should be re-factored into somewhere nearer the
-	# tips of the inheritance tree. The hack where we
-	# skip over direct instances of Writable is so that
-	# we don't register things like <format> and <matrix> tags
-	if ( ref $self ne 'Bio::Phylo::NeXML::Writable' ) {
-        	$taxamediator->register($self);
+        # TODO this is irrelevant for some child classes,
+        # so should be re-factored into somewhere nearer the
+        # tips of the inheritance tree. The hack where we
+        # skip over direct instances of Writable is so that
+        # we don't register things like <format> and <matrix> tags
+        if ( ref $self ne 'Bio::Phylo::NeXML::Writable' ) {
+            $taxamediator->register($self);
         }
         return $self;
     }
@@ -257,7 +253,7 @@ Sets invocant description.
 
         # notify user
         $logger->info("setting description '$desc'");
-        $desc{$self->get_id} = $desc;
+        $desc{ $self->get_id } = $desc;
         return $self;
     }
 
@@ -282,7 +278,7 @@ Sets invocant score.
         # $score must be a number (or undefined)
         if ( defined $score ) {
             if ( !looks_like_number($score) ) {
-            	throw 'BadNumber' => "score \"$score\" is a bad number";
+                throw 'BadNumber' => "score \"$score\" is a bad number";
             }
 
             # notify user
@@ -293,7 +289,7 @@ Sets invocant score.
         }
 
         # this resets the score if $score was undefined
-        $score{$self->get_id} = $score;
+        $score{ $self->get_id } = $score;
         return $self;
     }
 
@@ -325,7 +321,7 @@ Sets generic key/value pair(s).
         # retrieve id just once, don't call $self->get_id in loops, inefficient
         my $id = $self->get_id;
 
-        # this initializes the hash if it didn't exist yet, or resets it if no args
+     # this initializes the hash if it didn't exist yet, or resets it if no args
         if ( !defined $generic{$id} || !@_ ) {
             $generic{$id} = {};
         }
@@ -344,13 +340,13 @@ Sets generic key/value pair(s).
                 %args = looks_like_hash @_;
             }
 
-	    # notify user
-	    $logger->info("setting generic key/value pairs %{args}");
+            # notify user
+            $logger->info("setting generic key/value pairs %{args}");
 
-	    # fill up the hash
-	    foreach my $key ( keys %args ) {
-		$generic{$id}->{$key} = $args{$key};
-	    }
+            # fill up the hash
+            foreach my $key ( keys %args ) {
+                $generic{$id}->{$key} = $args{$key};
+            }
         }
         return $self;
     }
@@ -392,15 +388,17 @@ names with single quotes inside them (i.e. not around them) are "double quoted"
         my $self = shift;
         my $name = $self->get_internal_name;
         if ( $name =~ /\s/ && $name !~ /^'.+'$/ ) {
-        	$name =~ s/\s/_/g;
-        }        
-        if ( $name =~ /(?:\-|\^|\*|\(|\)|{|}|\[|\]|\+|=|;|:|"|\\|<|>|\/|,)/ && $name !~ /^'.+'$/ ) {
-        	$name = "'${name}'";
+            $name =~ s/\s/_/g;
+        }
+        if (   $name =~ /(?:\-|\^|\*|\(|\)|{|}|\[|\]|\+|=|;|:|"|\\|<|>|\/|,)/
+            && $name !~ /^'.+'$/ )
+        {
+            $name = "'${name}'";
         }
         if ( $name =~ /'/ && $name !~ /^".+"$/ && $name !~ /^'.+'$/ ) {
-        	$name = "\"${name}\"";
+            $name = "\"${name}\"";
         }
-        return $name;    
+        return $name;
     }
 
 =item get_internal_name()
@@ -446,7 +444,7 @@ Gets invocant description.
     sub get_desc {
         my $self = shift;
         $logger->debug("getting description");
-        return $desc{$self->get_id};
+        return $desc{ $self->get_id };
     }
 
 =item get_score()
@@ -465,7 +463,7 @@ Gets invocant's score.
     sub get_score {
         my $self = shift;
         $logger->debug("getting score");
-        return $score{$self->get_id};
+        return $score{ $self->get_id };
     }
 
 =item get_generic()
@@ -527,8 +525,7 @@ Gets a logger object.
  Args    : None
 
 =cut
-
-	sub get_logger { $logger }
+    sub get_logger { $logger }
 
 =back
 
@@ -579,8 +576,8 @@ Attempts to fetch an in-memory object by its UID
 =cut
 
     sub get_obj_by_id {
-	my ( $class, $id ) = @_;
-	return $objects{$id};
+        my ( $class, $id ) = @_;
+        return $objects{$id};
     }
 
 =item to_string()
@@ -597,15 +594,15 @@ Serializes object to general purpose string
 
 =cut
 
-	sub to_string {
-		my $self = shift;
-		my $class         = ref $self;
-		my $id            = $self->get_id;
-		my $internal_name = $self->get_internal_name;
-		my $name          = $self->get_name;
-		my $score         = $self->get_score;
-		my $desc          = $self->get_desc;
-return <<"SERIALIZED_OBJECT";
+    sub to_string {
+        my $self          = shift;
+        my $class         = ref $self;
+        my $id            = $self->get_id;
+        my $internal_name = $self->get_internal_name;
+        my $name          = $self->get_name;
+        my $score         = $self->get_score;
+        my $desc          = $self->get_desc;
+        return <<"SERIALIZED_OBJECT";
 class: $class
 id: $id
 internal_name: $internal_name
@@ -613,7 +610,7 @@ name: $name
 score: $score
 desc: $desc
 SERIALIZED_OBJECT
-	}
+    }
 
 =item clone()
 
@@ -634,71 +631,74 @@ Clones invocant.
     # classes because of the asymmetry between set_forest/get_forests,
     # set_node/get_nodes etc.
     sub clone {
-	my ( $self, %subs ) = @_;
+        my ( $self, %subs ) = @_;
 
-	# may not work yet! warn user
-	$logger->info("cloning is experimental, use with caution");
+        # may not work yet! warn user
+        $logger->info("cloning is experimental, use with caution");
 
-	# get inheritance tree
-	my ( $class, $isa, $seen ) = ( ref($self), [], {} );
-	_recurse_isa( $class, $isa, $seen );
+        # get inheritance tree
+        my ( $class, $isa, $seen ) = ( ref($self), [], {} );
+        _recurse_isa( $class, $isa, $seen );
 
-	# walk symbol table, get symmetrical set_foo/get_foo pairs
-	my %methods;
-	for my $package ( $class, @{$isa} ) {
-		my %symtable;
-		eval "\%symtable = \%${package}::"; 
-		SETTER: for my $setter ( keys %symtable ) {
-			next SETTER if $setter !~ m/^set_/;
-			my $getter = $setter;
-			$getter =~ s/^s/g/;
-			next SETTER if not exists $symtable{$getter};
+        # walk symbol table, get symmetrical set_foo/get_foo pairs
+        my %methods;
+        for my $package ( $class, @{$isa} ) {
+            my %symtable;
+            eval "\%symtable = \%${package}::";
+          SETTER: for my $setter ( keys %symtable ) {
+                next SETTER if $setter !~ m/^set_/;
+                my $getter = $setter;
+                $getter =~ s/^s/g/;
+                next SETTER if not exists $symtable{$getter};
 
-			# have a symmetrical set_foo/get_foo pair, check
-			# if they're code (not variables, for example)
-			my $get_ref = $class->can($getter);
-			my $set_ref = $class->can($setter);
-			if ( looks_like_instance( $get_ref, 'CODE' ) and looks_like_instance( $set_ref, 'CODE' ) ) {
-				$methods{$getter} = $setter;
-			}
-		}
-	}
+                # have a symmetrical set_foo/get_foo pair, check
+                # if they're code (not variables, for example)
+                my $get_ref = $class->can($getter);
+                my $set_ref = $class->can($setter);
+                if (    looks_like_instance( $get_ref, 'CODE' )
+                    and looks_like_instance( $set_ref, 'CODE' ) )
+                {
+                    $methods{$getter} = $setter;
+                }
+            }
+        }
 
-	# instantiate the clone
-	my @new;
-	if ( $subs{'new'} ) {
-		@new = @{ $subs{'new'} };
-		delete $subs{'new'};			
-	}
-	my $clone = $class->new(@new);
-	
-	# populate the clone		
-	for my $getter ( keys %methods ) {	    	
-		my $setter = $methods{$getter};
-		if ( exists $subs{$setter} ) {
-			$logger->info("method $setter for $clone overridden");
-			if ( looks_like_instance( $subs{$setter}, 'CODE' ) ) {
-				$subs{$setter}->( $self, $clone );
-			}
-			delete $subs{$setter};
-		}
-		else {
-			eval {
-				$logger->info("copying $getter => $setter");
-				my $value = $self->$getter;
-				if ( defined $value ) {
-					$clone->$setter($value);
-				}
-			};
-			if ($@) {
-				$logger->warn("failed copy of $getter => $setter: \n$@");
-			}
-		}
-	}
+        # instantiate the clone
+        my @new;
+        if ( $subs{'new'} ) {
+            @new = @{ $subs{'new'} };
+            delete $subs{'new'};
+        }
+        my $clone = $class->new(@new);
 
-	# execute additional code refs
-	$_->( $self, $clone ) for ( grep { looks_like_instance( $_, 'CODE' ) } values %subs );
-	return $clone;
+        # populate the clone
+        for my $getter ( keys %methods ) {
+            my $setter = $methods{$getter};
+            if ( exists $subs{$setter} ) {
+                $logger->info("method $setter for $clone overridden");
+                if ( looks_like_instance( $subs{$setter}, 'CODE' ) ) {
+                    $subs{$setter}->( $self, $clone );
+                }
+                delete $subs{$setter};
+            }
+            else {
+                eval {
+                    $logger->info("copying $getter => $setter");
+                    my $value = $self->$getter;
+                    if ( defined $value ) {
+                        $clone->$setter($value);
+                    }
+                };
+                if ($@) {
+                    $logger->warn("failed copy of $getter => $setter: \n$@");
+                }
+            }
+        }
+
+        # execute additional code refs
+        $_->( $self, $clone )
+          for ( grep { looks_like_instance( $_, 'CODE' ) } values %subs );
+        return $clone;
     }
 
 =item VERBOSE()
@@ -717,8 +717,8 @@ info on available verbosity levels.
 =cut
 
     # Verbosity is mostly handled by the logger, actually. This method
-    # is just here for backward compatibility (and ease of use). 
-    # TODO have a facility to turn log levels (warn/error/fatal) into 
+    # is just here for backward compatibility (and ease of use).
+    # TODO have a facility to turn log levels (warn/error/fatal) into
     # throws
     sub VERBOSE {
         my $class = shift;
@@ -747,7 +747,7 @@ Returns suggested citation.
 =cut
 
     sub CITATION {
-	return <<'CITATION';
+        return <<'CITATION';
 Rutger A Vos, Jason Caravas, Klaas Hartmann, Mark A Jensen and Chase Miller, 2011.
 Bio::Phylo - phyloinformatic analysis using Perl. BMC Bioinformatics 12:63.
 doi:10.1186/1471-2105-12-63
@@ -769,7 +769,6 @@ Gets version number (including revision number).
  Comments:
 
 =cut
-
     sub VERSION { $VERSION }
 
 =begin comment
@@ -790,52 +789,52 @@ Invocant destructor.
 =end comment
 
 =cut
+    {
+        no warnings 'recursion';
+        my %isa_for_class;
 
-{
-    no warnings 'recursion';
-    my %isa_for_class;
-    sub DESTROY {
-        my $self = shift;
+        sub DESTROY {
+            my $self = shift;
 
-	# delete from get_obj_by_id
-	my $id;
-	if ( defined( $id = $self->get_id ) ) {
-		delete $objects{$id};
-	}
-
-        # build full @ISA from child to here
-        my $class = ref $self;
-	my $isa;
-	unless( $isa = $isa_for_class{$class} ) {
-		$isa = [];
-		my $seen = {};
-	        _recurse_isa( $class, $isa, $seen );
-	        $isa_for_class{$class} = $isa;
-        }
-
-        # call *all* _cleanup methods, wouldn't work if simply SUPER::_cleanup
-        # given multiple inheritance
-        {
-            no strict 'refs'; 
-            for my $SUPER ( @{$isa} ) {
-            	if ( $SUPER->can('_cleanup') ) {
-	                my $cleanup = "${SUPER}::_cleanup";
-	                $self->$cleanup;
-            	}
+            # delete from get_obj_by_id
+            my $id;
+            if ( defined( $id = $self->get_id ) ) {
+                delete $objects{$id};
             }
-            use strict;
+
+            # build full @ISA from child to here
+            my $class = ref $self;
+            my $isa;
+            unless ( $isa = $isa_for_class{$class} ) {
+                $isa = [];
+                my $seen = {};
+                _recurse_isa( $class, $isa, $seen );
+                $isa_for_class{$class} = $isa;
+            }
+
+          # call *all* _cleanup methods, wouldn't work if simply SUPER::_cleanup
+          # given multiple inheritance
+            {
+                no strict 'refs';
+                for my $SUPER ( @{$isa} ) {
+                    if ( $SUPER->can('_cleanup') ) {
+                        my $cleanup = "${SUPER}::_cleanup";
+                        $self->$cleanup;
+                    }
+                }
+                use strict;
+            }
+
+            #$logger->debug("done cleaning up '$self'"); # XXX
+            # cleanup from mediator
+            $taxamediator->unregister($self);
+
+            # done cleaning up, id can be reclaimed
+            Bio::Phylo::Util::IDPool->_reclaim($self);
         }
-        $logger->debug("done cleaning up '$self'"); # XXX
-
-        # cleanup from mediator
-        $taxamediator->unregister($self);
-
-        # done cleaning up, id can be reclaimed
-        Bio::Phylo::Util::IDPool->_reclaim($self);
     }
-}
 
-    # starting from $class, push all superclasses (+$class) into @$isa, 
+    # starting from $class, push all superclasses (+$class) into @$isa,
     # %$seen is just a helper to avoid getting stuck in cycles
     sub _recurse_isa {
         my ( $class, $isa, $seen ) = @_;
@@ -844,7 +843,7 @@ Invocant destructor.
             push @{$isa}, $class;
             my @isa;
             {
-                no strict 'refs'; 
+                no strict 'refs';
                 @isa = @{"${class}::ISA"};
                 use strict;
             }
@@ -857,14 +856,15 @@ Invocant destructor.
     # be inside-out objects).
     sub _cleanup {
         my $self = shift;
-        $logger->debug("cleaning up '$self'"); # XXX
+
+        #$logger->debug("cleaning up '$self'"); # XXX
         my $id = $self->get_id;
 
         # cleanup local fields
         if ( defined $id ) {
-	        for my $field (@fields) {
-	            delete $field->{$id};
-	        }
+            for my $field (@fields) {
+                delete $field->{$id};
+            }
         }
     }
 
@@ -884,7 +884,7 @@ Invocant destructor.
 
     # this is the converse of $listable->get_entities, i.e.
     # every entity in a listable object holds a reference
-    # to its container. We actually use this surprisingly 
+    # to its container. We actually use this surprisingly
     # rarely, and because I read somewhere (heh) it's bad
     # to have the objects of a has-a relationship fiddle with
     # their container we hide this method from abuse. Then
@@ -913,26 +913,27 @@ Invocant destructor.
         my $id = $self->get_id;
         if ( blessed $container ) {
             if ( $container->can('can_contain') ) {
-                if ( $container->can_contain( $self ) ) {
+                if ( $container->can_contain($self) ) {
                     if ( $container->contains($self) ) {
                         $container{$id} = $container;
                         weaken( $container{$id} );
                         return $self;
                     }
                     else {
-                    	throw 'ObjectMismatch' => "'$self' not in '$container'";
+                        throw 'ObjectMismatch' => "'$self' not in '$container'";
                     }
                 }
                 else {
-                	throw 'ObjectMismatch' => "'$container' cannot contain '$self'";
+                    throw 'ObjectMismatch' =>
+                      "'$container' cannot contain '$self'";
                 }
             }
             else {
-            	throw 'ObjectMismatch' => "Invalid objects";
+                throw 'ObjectMismatch' => "Invalid objects";
             }
         }
         else {
-        	throw 'BadArgs' => "Argument not an object";
+            throw 'BadArgs' => "Argument not an object";
         }
     }
 
@@ -953,10 +954,8 @@ L<http://dx.doi.org/10.1186/1471-2105-12-63>
 
 =head1 REVISION
 
- $Id: Phylo.pm 1641 2011-03-30 17:27:58Z rvos $
+ $Id: Phylo.pm 1660 2011-04-02 18:29:40Z rvos $
 
 =cut
-
 }
-
 1;
